# Installation

## Prerequisites

Ensure the following are installed:

- [Python](https://www.python.org/downloads/) (a version between 3.8 - 3.11)
- [pip](https://pip.pypa.io/en/stable/installation/)

## Installation with pip

<!-- start installation -->

Install the latest version of [`dhlab`](https://pypi.org/project/dhlab/) in your (Unix) terminal with pip:

```shell
pip install -U dhlab
```

## Installation from github

- Ensure you have [git](https://git-scm.com/downloads) installed on your system.
- Open your terminal in the file location you will work with [DHLAB](https://github.com/NationalLibraryOfNorway/DHLAB).

``` shell
git clone https://github.com/NationalLibraryOfNorway/DHLAB.git
cd DHLAB
pip install -U -e .
```

<!-- end installation -->
